%define anolis_release 3

Name:    trousers
Version: 0.3.15
Release: %{anolis_release}%{?dist}
Summary: The open-source TCG Software Stack
License: BSD
Url:     http://trousers.sourceforge.net
Source0: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1: tcsd.service

Patch1: trousers-0.3.14-noinline.patch
Patch2: trousers-0.3.14-unlock-in-err-path.patch

BuildRequires: autoconf automake make
BuildRequires: libtool openssl-devel gettext-devel systemd
Requires(pre): shadow-utils
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Requires: %{name}-lib = %{version}-%{release}

%description
TrouSerS is an implementation of the Trusted Computing Group's Software Stack
(TSS) specification. You can use TrouSerS to write applications that make use
of your TPM hardware. TPM hardware can create, store and use RSA keys
securely (without ever being exposed in memory), verify a platform's software
state using cryptographic hashes and more.

%package lib
Summary: TrouSerS libtspi library
Obsoletes: trousers < 0.3.13-4

%description lib
The libtspi library for use in Trusted Computing enabled applications.

%package devel
Summary: TrouSerS header files and documentation
Requires: %{name}-lib = %{version}-%{release}

%description devel
Header files and man pages for use in creating Trusted Computing enabled
applications.

%package static
Summary: TrouSerS TCG Device Driver Library
Requires: %{name}-devel = %{version}-%{release}

%description static
The TCG Device Driver Library (TDDL) used by the TrouSerS tcsd as the
interface to the TPM's device driver. For more information about writing
applications to the TDDL interface, see the latest TSS spec at
https://www.trustedcomputinggroup.org/specs/TSS.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}
sed -i -e 's|/var/tpm|/var/lib/tpm|g' -e 's|/usr/local/var|/var|g' man/man5/tcsd.conf.5.in man/man8/tcsd.8.in

%build
chmod +x ./bootstrap.sh
./bootstrap.sh
%configure --with-gui=openssl
%make_build -k

%install
mkdir -p %{buildroot}%{_localstatedir}/lib/tpm
%make_install
find %{buildroot} -type f -name '*.la' -print -delete
mkdir -p %{buildroot}%{_unitdir}
install -Dpm0644 %{SOURCE1} %{buildroot}%{_unitdir}/

%generate_compatibility_deps

%pre
getent group tss >/dev/null || groupadd -f -g 59 -r tss
if ! getent passwd tss >/dev/null ; then
    if ! getent passwd 59 >/dev/null ; then
      useradd -r -u 59 -g tss -d /dev/null -s /sbin/nologin -c "Account used for TPM access" tss
    else
      useradd -r -g tss -d /dev/null -s /sbin/nologin -c "Account used for TPM access" tss
    fi
fi
exit 0

%post
%systemd_post tcsd.service

%preun
%systemd_preun tcsd.service

%postun
%systemd_postun_with_restart tcsd.service 

%files
%{_sbindir}/tcsd
%config(noreplace) %attr(0640, root, tss) %{_sysconfdir}/tcsd.conf
%attr(644,root,root) %{_unitdir}/tcsd.service
%attr(0700, tss, tss) %{_localstatedir}/lib/tpm/
%{_mandir}/man5/*
%{_mandir}/man8/*

%files lib
%dir %{abidir}
%license LICENSE
%{_libdir}/libtspi.so.1*
%{abidir}/libtspi.dump

%files devel
%{_libdir}/libtspi.so
%{_includedir}/tss/
%{_includedir}/trousers/
%{_mandir}/man3/Tspi_*
%doc doc/LTC-TSS_LLD_08_r2.pdf doc/TSS_programming_SNAFUs.txt

%files static
%{_libdir}/libtddl.a

%files doc
%doc README ChangeLog

%changelog
* Wed Apr 12 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 0.3.15-3
- Optimize the spec file

* Sun Mar 19 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 0.3.15-2
- Optimize the spec file

* Thu Mar 10 2022 Mingyue Zhao <wb-zmy745940@alibaba-inc.com> - 0.3.15-1
- Init for Anolis OS 23
